.nj-alert{position:relative;display:flex;align-items:center;margin:1rem 0;padding:.5rem 3rem .5rem 1rem;color:var(--nj-color-text-background-base);font-size:0.875rem}.nj-alert__icon{margin-right:1rem}.nj-alert__icon,.nj-alert__icon.material-icons{color:inherit}.nj-alert__title{display:block;font-weight:700}.nj-alert__close{padding:.5rem 1rem;position:absolute;top:0;right:0;opacity:1;color:var(--nj-color-text-background-base)}.nj-alert__close:hover{text-decoration:none}.nj-alert__close:not(:disabled):not(.disabled):hover,.nj-alert__close:not(:disabled):not(.disabled):focus{opacity:.7}a.nj-alert__close{pointer-events:none}button.nj-alert__close{background-color:transparent;border:0;-webkit-appearance:none;appearance:none}.nj-alert__close-icon{display:block;font-size:1.125rem}.nj-alert__close-icon,.nj-alert__close-icon.material-icons{color:inherit}.nj-alert--primary{background-color:var(--nj-color-base-primary)}.nj-alert--success{background-color:var(--nj-color-base-success)}.nj-alert--warning{background-color:var(--nj-color-base-warning)}.nj-alert--danger{background-color:var(--nj-color-base-danger)}.nj-alert--light{background-color:var(--nj-color-base-light)}.nj-alert--light{color:var(--nj-color-base-primary)}.nj-alert--light .nj-alert__close{color:var(--nj-color-text-body)}
