.position-static{position:static !important}.position-relative{position:relative !important}.position-absolute{position:absolute !important}.position-fixed{position:fixed !important}.position-sticky{position:-webkit-sticky !important;position:sticky !important}.fixed-top{position:fixed;top:0;right:0;left:0;z-index:var(--nj-elevation-fixed)}.fixed-bottom{position:fixed;right:0;bottom:0;left:0;z-index:var(--nj-elevation-fixed)}@supports ((position: -webkit-sticky) or (position: sticky)){.sticky-top{position:-webkit-sticky;position:sticky;top:0;z-index:var(--nj-elevation-sticky)}}
