.nj-shadow-2dp{box-shadow:var(--nj-shadow-level-2-dp)}.nj-shadow-4dp{box-shadow:var(--nj-shadow-level-4-dp)}.nj-shadow-6dp{box-shadow:var(--nj-shadow-level-6-dp)}.nj-shadow-8dp{box-shadow:var(--nj-shadow-level-8-dp)}.nj-shadow-16dp{box-shadow:var(--nj-shadow-level-16-dp)}.nj-shadow-24dp{box-shadow:var(--nj-shadow-level-24-dp)}.nj-shadow-none{box-shadow:none !important}
