.nj-progress{position:relative;height:.5rem;background-color:var(--nj-color-background-progress-track);border-radius:var(--nj-size-border-radius)}.nj-progress,.nj-progress :root{--nj-color-background-progress-track: var(--nj-color-base-gray-200);--nj-color-text-progress: var(--nj-color-base-gray-500)}[data-theme="dark"] .nj-progress,.nj-progress[data-theme="dark"]{--nj-color-background-progress-track: var(--nj-color-base-gray-500);--nj-color-text-progress: var(--nj-color-base-white-500)}.nj-progress__bar{width:0;height:.5rem;background-color:var(--nj-color-base-primary);border-radius:var(--nj-size-border-radius);transition:width 0.3s}@media screen and (prefers-reduced-motion: reduce){.nj-progress__bar{transition:none}}.nj-progress__text{width:100%;margin-top:.4rem;color:var(--nj-color-text-progress);font-size:1rem;text-align:center}.nj-progress--blue-allports .nj-progress__bar{background-color:var(--nj-color-base-blue-allports)}.nj-progress--blue-corporate .nj-progress__bar{background-color:var(--nj-color-base-blue-corporate)}.nj-progress--white .nj-progress__bar{background-color:var(--nj-color-base-white)}.nj-progress--green-java .nj-progress__bar{background-color:var(--nj-color-base-green-java)}.nj-progress--orange-crusta .nj-progress__bar{background-color:var(--nj-color-base-orange-crusta)}.nj-progress--purple .nj-progress__bar{background-color:var(--nj-color-base-purple)}.nj-progress--red-mandy .nj-progress__bar{background-color:var(--nj-color-base-red-mandy)}.nj-progress--yellow-bright-sun .nj-progress__bar{background-color:var(--nj-color-base-yellow-bright-sun)}.nj-progress--red .nj-progress__bar{background-color:var(--nj-color-base-red)}.nj-progress--green .nj-progress__bar{background-color:var(--nj-color-base-green)}.nj-progress--orange .nj-progress__bar{background-color:var(--nj-color-base-orange)}.nj-progress--blue-bigstone .nj-progress__bar{background-color:var(--nj-color-base-blue-bigstone)}.nj-progress--blue-rhino .nj-progress__bar{background-color:var(--nj-color-base-blue-rhino)}.nj-progress--blue-venice .nj-progress__bar{background-color:var(--nj-color-base-blue-venice)}.nj-progress--cerise .nj-progress__bar{background-color:var(--nj-color-base-cerise)}.nj-progress--green-fun .nj-progress__bar{background-color:var(--nj-color-base-green-fun)}.nj-progress--green-pine .nj-progress__bar{background-color:var(--nj-color-base-green-pine)}.nj-progress--green-riogrande .nj-progress__bar{background-color:var(--nj-color-base-green-riogrande)}.nj-progress--violet-eggplant .nj-progress__bar{background-color:var(--nj-color-base-violet-eggplant)}.nj-progress--violet .nj-progress__bar{background-color:var(--nj-color-base-violet)}.nj-progress--yellow .nj-progress__bar{background-color:var(--nj-color-base-yellow)}
