.nj-link{position:relative;color:#009de9}.nj-link:hover{color:#009de9;text-decoration:none}.nj-link:not(.stretched-link){padding-bottom:2px;background-image:linear-gradient(rgba(0,157,233,0.2), rgba(0,157,233,0.2)),linear-gradient(#009de9, #009de9);background-repeat:no-repeat;background-position:0 100%, 0 100%;background-size:100% 1px, 0 1px;transition-property:background-size;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:.3s}.nj-link:not(.stretched-link):hover{background-size:100% 1px, 100% 1px}.nj-link:not(.stretched-link).nj-link-icon{background-size:calc(100% - 18px - .5rem) 1px,0 1px}.nj-link:not(.stretched-link).nj-link-icon i{margin-left:.5rem;color:inherit;font-size:18px;vertical-align:sub}.nj-link:not(.stretched-link).nj-link-icon i:hover{color:inherit}.nj-link:not(.stretched-link).nj-link-icon:hover{background-size:calc(100% - 18px - .5rem) 1px,calc(100% - 18px - .5rem) 1px}.nj-link:not(.stretched-link).nj-link-icon--before{background-position:calc(18px + .5rem) 100%,calc(18px + .5rem) 100%}.nj-link:not(.stretched-link).nj-link-icon--before i{margin-right:.5rem;margin-left:0}.nj-link--primary:not(.stretched-link){color:#009de9;background-image:linear-gradient(rgba(0,157,233,0.2), rgba(0,157,233,0.2)),linear-gradient(#009de9, #009de9)}.nj-link--primary:not(.stretched-link) i{color:#009de9}.nj-link--primary:not(.stretched-link):hover{color:#009de9}.nj-link--success:not(.stretched-link){color:#009934;background-image:linear-gradient(rgba(0,153,52,0.2), rgba(0,153,52,0.2)),linear-gradient(#009934, #009934)}.nj-link--success:not(.stretched-link) i{color:#009934}.nj-link--success:not(.stretched-link):hover{color:#009934}.nj-link--warning:not(.stretched-link){color:#e07602;background-image:linear-gradient(rgba(224,118,2,0.2), rgba(224,118,2,0.2)),linear-gradient(#e07602, #e07602)}.nj-link--warning:not(.stretched-link) i{color:#e07602}.nj-link--warning:not(.stretched-link):hover{color:#e07602}.nj-link--danger:not(.stretched-link){color:#c03;background-image:linear-gradient(rgba(204,0,51,0.2), rgba(204,0,51,0.2)),linear-gradient(#c03, #c03)}.nj-link--danger:not(.stretched-link) i{color:#c03}.nj-link--danger:not(.stretched-link):hover{color:#c03}.nj-link--light:not(.stretched-link){color:#fff;background-image:linear-gradient(rgba(255,255,255,0.2), rgba(255,255,255,0.2)),linear-gradient(#fff, #fff)}.nj-link--light:not(.stretched-link) i{color:#fff}.nj-link--light:not(.stretched-link):hover{color:#fff}
