.nj-toggle,.nj-toggle :root{--toggle-background-color: var(--nj-color-base-gray-400);--color-background-toggle-disabled: var(--nj-color-base-gray-200)}[data-theme="dark"] .nj-toggle,.nj-toggle[data-theme="dark"]{--toggle-background-color: var(--nj-color-base-gray-400);--color-background-toggle-disabled: var(--nj-color-base-white-200)}.nj-toggle label{display:flex;align-items:center;margin-bottom:0;cursor:pointer}.nj-toggle input[type="checkbox"]{position:absolute;left:0;z-index:-1;width:0;height:0;margin:0;overflow:hidden;opacity:0;pointer-events:none}.nj-toggle input[type="checkbox"]:checked ~ .nj-toggle__track::before{transform:translateX(16px)}.nj-toggle input[type="checkbox"]:checked ~ .nj-toggle__track{background-color:var(--nj-color-base-primary)}.nj-toggle__track{position:relative;display:block;width:32px;height:16px;background-color:var(--toggle-background-color);border-radius:16px;transition:background-color .25s linear}.nj-toggle__track::before{position:absolute;top:2px;left:2px;width:12px;height:12px;background-color:var(--nj-color-background-components);border-radius:16px;transform:translateX(0);transition:transform .25s ease-in-out;content:""}.nj-toggle__icon-dm{display:block;width:16px;height:16px;fill:var(--nj-color-text-body)}.nj-toggle--primary input[type="checkbox"]:checked ~ .nj-toggle__track{background-color:#009de9}.nj-toggle--success input[type="checkbox"]:checked ~ .nj-toggle__track{background-color:#009934}.nj-toggle--warning input[type="checkbox"]:checked ~ .nj-toggle__track{background-color:#e07602}.nj-toggle--danger input[type="checkbox"]:checked ~ .nj-toggle__track{background-color:#c03}.nj-toggle--light input[type="checkbox"]:checked ~ .nj-toggle__track{background-color:#fff}.nj-toggle input[type="checkbox"]:disabled ~ .nj-toggle__track{background-color:var(--color-background-toggle-disabled)}
