.nj-slider{--slider-track-bg:var(--nj-color-base-gray-200);--slider-track-position: 50% 100%;position:relative}[data-theme="dark"] .nj-slider,.nj-slider[data-theme="dark"]{--slider-track-bg:var(--nj-color-base-gray-500)}.nj-slider input[type="range"]{display:block;width:100%;height:calc(16px + .4rem);padding:0;background-color:transparent;-webkit-appearance:none}.nj-slider input[type="range"]:focus{outline:none}.nj-slider input[type="range"]:focus::-webkit-slider-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .2rem rgba(0,157,233,0.25)}.nj-slider input[type="range"]:focus::-moz-range-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .2rem rgba(0,157,233,0.25)}.nj-slider input[type="range"]:focus::-ms-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .2rem rgba(0,157,233,0.25)}.nj-slider input[type="range"]::-moz-focus-outer{border:0}.nj-slider input[type="range"]::-webkit-slider-thumb{width:16px;height:16px;margin-top:calc((.2rem - 16px) / 2);background-color:#009de9;border:0;border-radius:1rem;box-shadow:0 0.1rem 0.25rem rgba(0,0,0,0.1);-webkit-transition:background-color 0.15s ease-in-out,border-color 0.15s ease-in-out,box-shadow 0.15s ease-in-out;transition:background-color 0.15s ease-in-out,border-color 0.15s ease-in-out,box-shadow 0.15s ease-in-out;-webkit-appearance:none}@media screen and (prefers-reduced-motion: reduce){.nj-slider input[type="range"]::-webkit-slider-thumb{-webkit-transition:none;transition:none}}.nj-slider input[type="range"]::-webkit-slider-thumb:active{background-color:#0074ac}.nj-slider input[type="range"]::-webkit-slider-runnable-track{width:100%;height:.2rem;color:transparent;background:linear-gradient(#009de9, #009de9) no-repeat var(--slider-track-bg);background-size:var(--slider-track-position);border-color:transparent;border-radius:1rem;box-shadow:inset 0 0.25rem 0.25rem rgba(0,0,0,0.1);cursor:pointer}.nj-slider input[type="range"]::-moz-range-track{width:100%;height:.2rem;color:transparent;background:linear-gradient(#009de9, #009de9) no-repeat var(--slider-track-bg);background-size:var(--slider-track-position);border-color:transparent;border-radius:1rem;box-shadow:inset 0 0.25rem 0.25rem rgba(0,0,0,0.1);cursor:pointer}.nj-slider input[type="range"]::-moz-range-thumb{width:16px;height:16px;background-color:#009de9;border:0;border-radius:1rem;box-shadow:0 0.1rem 0.25rem rgba(0,0,0,0.1);-moz-transition:background-color 0.15s ease-in-out,border-color 0.15s ease-in-out,box-shadow 0.15s ease-in-out;transition:background-color 0.15s ease-in-out,border-color 0.15s ease-in-out,box-shadow 0.15s ease-in-out;appearance:none}@media screen and (prefers-reduced-motion: reduce){.nj-slider input[type="range"]::-moz-range-thumb{-moz-transition:none;transition:none}}.nj-slider input[type="range"]::-moz-range-thumb:active{background-color:#0074ac}.nj-slider input[type="range"]::-ms-thumb{width:16px;height:16px;margin-top:0;margin-right:.2rem;margin-left:.2rem;background-color:#009de9;border:0;border-radius:1rem;box-shadow:0 0.1rem 0.25rem rgba(0,0,0,0.1);-ms-transition:background-color 0.15s ease-in-out,border-color 0.15s ease-in-out,box-shadow 0.15s ease-in-out;transition:background-color 0.15s ease-in-out,border-color 0.15s ease-in-out,box-shadow 0.15s ease-in-out;appearance:none}@media screen and (prefers-reduced-motion: reduce){.nj-slider input[type="range"]::-ms-thumb{-ms-transition:none;transition:none}}.nj-slider input[type="range"]::-ms-thumb:active{background-color:#0074ac}.nj-slider input[type="range"]::-ms-track{width:100%;height:5px;color:transparent;background:linear-gradient(#009de9, #009de9) no-repeat transparent;background-size:var(--slider-track-position);border-color:transparent;cursor:pointer}.nj-slider input[type="range"]::-ms-fill-upper{background-color:var(--slider-track-bg);border-radius:1rem}.nj-slider input[type="range"]:disabled::-webkit-slider-thumb{background-color:#9e9e9e}.nj-slider input[type="range"]:disabled::-webkit-slider-runnable-track{cursor:default}.nj-slider input[type="range"]:disabled::-moz-range-thumb{background-color:#9e9e9e}.nj-slider input[type="range"]:disabled::-moz-range-track{cursor:default}.nj-slider input[type="range"]:disabled::-ms-thumb{background-color:#9e9e9e}.nj-slider[data-tooltip="true"] input[type="range"]{margin-top:38px}.nj-slider .nj-tooltip{bottom:24px}.nj-slider .nj-tooltip .nj-tooltip__arrow{left:calc(50% - .4rem)}
