/*

This rules provide the CubicWeb compatibily and are ment to be used in production

:organization: Logilab
:copyright: 2013 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
:contact: https://www.logilab.fr/ -- mailto:contact@logilab.fr
*/

/* CW compatibility */
/*----------------------------------- */

/* LISTS */
#relatedEntities ul,
ul.boxListing {
  list-style: none outside none;
  padding-left: 0;
  margin: 0;
 }

/* FORMS  */
/*----------------------------------- */

input, select, textarea {
  height: 34px;
  padding: 6px 6px;
  font-size: 14px;
  line-height: 1.428571429;
  color: #555555;
  vertical-align: middle;
  background-color: #ffffff;
  border: 1px solid #cccccc;
  border-radius: 4px;
}

select {
  background-color: #FFFFFF;
  border-radius: 3px;
  padding-right: 2px;
}

input[type="file"] {
  border: none;
  border-radius: 0;
  box-shadow: none;
  height: auto;
}

iframe {
  border: 0;
}

/* equal to label */
.labelCol {
   display: inline-block;
   margin-bottom: 5px;
 }

.iformTitle > span {
   font-weight: bold;
 }


/* PREFERENCES */
/*----------------------------------- */

.ctxcomponents.preferences,
.preffield {
  border: 1px solid #ccc;
  border-radius: 4px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05) inset;
}

form div.preffield {
  background-color: #f5f5f5;
  margin-bottom: 1em;
}

.lead a{
 color: #333;
 }