.nj-modal{--modal-close-color: var(--nj-color-base-gray-900);position:fixed;top:0;left:0;z-index:var(--nj-elevation-modal);display:none;width:100%;height:100%;overflow:hidden;outline:0}[data-theme="dark"] .nj-modal,.nj-modal[data-theme="dark"]{--modal-close-color: var(--nj-color-base-primary)}.nj-modal--visible{display:block}.nj-modal--visible.nj-modal--vertical-centered{display:flex}.nj-modal--vertical-centered{align-items:center;justify-content:center;width:100%}.nj-modal__dialog{position:relative;width:auto;max-width:560px;margin:.5rem;pointer-events:none}@media (min-width: 576px){.nj-modal__dialog{margin:1.75rem auto}}.nj-modal__dialog.nj-modal--sm{max-width:440px}.nj-modal.fade .nj-modal__dialog{transition:transform 0.3s ease-out;transform:translate(0, -50px)}@media screen and (prefers-reduced-motion: reduce){.nj-modal.fade .nj-modal__dialog{transition:none}}.nj-modal.show .nj-modal__dialog{transform:none}.nj-modal--vertical-centered .nj-modal__dialog{width:100%}.nj-modal__content{position:relative;display:flex;flex-direction:column;width:100%;padding:var(--nj-size-padding-modal);color:inherit;background-color:var(--nj-color-background-components);background-clip:padding-box;outline:0;box-shadow:var(--nj-shadow-level-24-dp);pointer-events:auto}.nj-modal__backdrop{position:fixed;top:0;left:0;z-index:var(--nj-elevation-modal-backdrop);width:100vw;height:100vh;background-color:var(--nj-color-backdrop-modal)}.nj-modal__backdrop.fade{opacity:0}.nj-modal__backdrop.show{opacity:.5}.nj-modal__header{display:flex;flex-direction:column-reverse;align-items:flex-start;justify-content:space-between;padding:0 0 1.5rem}.nj-modal__header .nj-close{margin:1rem 1rem 0 0;padding:1rem 1rem}.nj-modal__title{margin-bottom:0;line-height:1.5}.nj-modal__close{display:flex;align-items:center;justify-content:center;box-sizing:content-box;width:1rem;height:1rem;padding:1.5rem;position:absolute;top:0;right:0;opacity:1}.nj-modal__close:hover{text-decoration:none}.nj-modal__close:not(:disabled):not(.disabled):hover,.nj-modal__close:not(:disabled):not(.disabled):focus{opacity:.7}a.nj-modal__close{pointer-events:none}button.nj-modal__close{background-color:transparent;border:0;-webkit-appearance:none;appearance:none}.nj-modal__close .close-icon{color:var(--modal-close-color)}.nj-modal__close-icon{display:block;color:#fff;font-size:1.125rem}.nj-modal__body{position:relative;flex:1 1 auto}.nj-modal__body p:last-of-type{margin-bottom:0}.nj-modal__footer{display:flex;align-items:center;justify-content:flex-end;padding:var(--nj-size-padding-modal) 0 0}.nj-modal__footer>:not(:first-child){margin-left:.25rem}.nj-modal__footer>:not(:last-child){margin-right:.25rem}
