.nj-list-group{--list-group-border-color: var(--nj-color-base-gray-300);--list-group-hover-color: var(--nj-color-base-gray-100);--list-group-icon-color: var(--nj-color-base-gray-600);display:flex;flex-direction:column;flex-grow:1;padding:0;overflow:hidden;background-color:var(--nj-color-background-components)}[data-theme="dark"] .nj-list-group,.nj-list-group[data-theme="dark"]{--list-group-border-color: var(--nj-color-base-gray-400);--list-group-hover-color: var(--nj-color-base-gray-600);--list-group-icon-color: var(--nj-color-base-gray-400)}.nj-list-group--no-border .nj-list-group__item{border-bottom:0}.nj-list-group__item{position:relative;display:flex;flex-flow:row nowrap;align-items:flex-start;padding:1.5rem 1.5rem 1.5rem calc(1.5rem - 2px);color:inherit;line-height:1.5rem;background-color:var(--nj-color-background-components);border-top:0;border-right:0;border-bottom:1px solid var(--list-group-border-color);border-left:2px solid transparent;font-size:1rem;transition:color 0.15s,background 0.15s,border-color 0.15s}@media screen and (prefers-reduced-motion: reduce){.nj-list-group__item{transition:none}}.nj-list-group__item h5{font-weight:700}.nj-list-group__item:last-child{margin-bottom:0;border-bottom:0}.nj-list-group__item:hover,.nj-list-group__item:focus{z-index:1;text-decoration:none}.nj-list-group__item.disabled,.nj-list-group__item:disabled{color:var(--nj-color-base-disabled);pointer-events:none}.nj-list-group__item.active{z-index:2;background-color:var(--nj-color-background-components-active);border-left-color:var(--nj-color-base-primary)}.nj-list-group__item.active,.nj-list-group__item.active i{transition:color 0.15s,background 0.15s,border-color 0.15s}@media screen and (prefers-reduced-motion: reduce){.nj-list-group__item.active,.nj-list-group__item.active i{transition:none}}.nj-list-group__item.active i{color:#009de9}.nj-list-group__item .material-icons{color:var(--list-group-icon-color)}.nj-list-group a.nj-list-group__item,.nj-list-group button.nj-list-group__item{width:100%;text-align:inherit}.nj-list-group a.nj-list-group__item:hover,.nj-list-group a.nj-list-group__item:focus,.nj-list-group button.nj-list-group__item:hover,.nj-list-group button.nj-list-group__item:focus{color:var(--nj-color-base-primary);text-decoration:none;background-color:var(--list-group-hover-color)}.nj-list-group a.nj-list-group__item:active,.nj-list-group button.nj-list-group__item:active{z-index:2;background-color:var(--nj-color-background-components-active);border-left-color:var(--nj-color-base-primary)}.nj-list-group a.nj-list-group__item:active,.nj-list-group a.nj-list-group__item:active i,.nj-list-group button.nj-list-group__item:active,.nj-list-group button.nj-list-group__item:active i{transition:color 0.15s,background 0.15s,border-color 0.15s}@media screen and (prefers-reduced-motion: reduce){.nj-list-group a.nj-list-group__item:active,.nj-list-group a.nj-list-group__item:active i,.nj-list-group button.nj-list-group__item:active,.nj-list-group button.nj-list-group__item:active i{transition:none}}.nj-list-group a.nj-list-group__item:active i,.nj-list-group button.nj-list-group__item:active i{color:#009de9}.nj-list-group--sm .nj-list-group__item{padding:0.75rem 1rem 0.75rem calc(1rem - 2px)}
