.nj-sidebar{--nj-sidebar-width: 300px;--nj-sidebar-width-folded: 72px;--nj-sidebar-sm-width-folded: 58px;position:fixed;top:0;z-index:calc(var(--nj-elevation-fixed) - 1);display:block;width:var(--nj-sidebar-width);height:100vh;overflow-x:hidden;background-color:var(--nj-color-background-components);border-right:1px solid var(--nj-color-base-gray-200);transition:width 0.2s cubic-bezier(0.4, 0, 0.2, 1)}[data-theme="dark"] .nj-sidebar,.nj-sidebar[data-theme="dark"]{border:none}.nj-sidebar__brand{display:block;margin:2rem auto;text-align:center}.nj-sidebar__logo{display:inline-block}.nj-sidebar__logo--folded{display:none}.nj-sidebar__navigation{width:var(--nj-sidebar-width);margin:0}.nj-sidebar__navigation.nj-list-group .nj-list-group__item:hover,.nj-sidebar__navigation.nj-list-group .nj-list-group__item:active,.nj-sidebar__navigation.nj-list-group .nj-list-group__item:focus{color:inherit}.nj-sidebar--folded{width:var(--nj-sidebar-width-folded)}.nj-sidebar--folded.nj-sidebar--sm{width:var(--nj-sidebar-sm-width-folded)}.nj-sidebar--folded .nj-sidebar__fold-btn .material-icons{transform:rotate(-180deg)}.nj-sidebar--folded .nj-sidebar__logo{display:none}.nj-sidebar--folded .nj-sidebar__logo--folded{display:inline-block}.nj-sidebar--folded+.nj-sidebar-content{margin-left:72px}.nj-sidebar--navbar{top:var(--nj-size-height-navbar-normal);height:calc(100vh - var(--nj-size-height-navbar-normal))}@media (max-width: 767.98px){.nj-sidebar--navbar{top:var(--nj-size-height-navbar-small);min-height:calc(100vh - var(--nj-size-height-navbar-small))}}.nj-sidebar-content{margin-left:300px;transition:margin-left 0.2s cubic-bezier(0.4, 0, 0.2, 1)}nj-sidebar[folded]+.nj-sidebar-content{margin-left:72px}
