.border,.border-top,.border-right,.border-bottom,.border-left{--border-color: var(--nj-color-base-black-100)}.border{border:var(--nj-size-border-width) solid var(--border-color) !important}.border-top{border-top:var(--nj-size-border-width) solid var(--border-color) !important}.border-right{border-right:var(--nj-size-border-width) solid var(--border-color) !important}.border-bottom{border-bottom:var(--nj-size-border-width) solid var(--border-color) !important}.border-left{border-left:var(--nj-size-border-width) solid var(--border-color) !important}.border-0{border:0 !important}.border-top-0{border-top:0 !important}.border-right-0{border-right:0 !important}.border-bottom-0{border-bottom:0 !important}.border-left-0{border-left:0 !important}.border-primary{border-color:css-var(color-base, "primary") !important}.border-success{border-color:css-var(color-base, "success") !important}.border-warning{border-color:css-var(color-base, "warning") !important}.border-danger{border-color:css-var(color-base, "danger") !important}.border-light{border-color:css-var(color-base, "light") !important}.border-white{border-color:#fff !important}.rounded{border-radius:var(--nj-size-border-radius) !important}.rounded--sm{border-radius:.125rem !important}.rounded--lg{border-radius:.5rem !important}.rounded-top{border-top-left-radius:var(--nj-size-border-radius) !important;border-top-right-radius:var(--nj-size-border-radius) !important}.rounded-right{border-top-right-radius:var(--nj-size-border-radius) !important;border-bottom-right-radius:var(--nj-size-border-radius) !important}.rounded-bottom{border-bottom-right-radius:var(--nj-size-border-radius) !important;border-bottom-left-radius:var(--nj-size-border-radius) !important}.rounded-left{border-top-left-radius:var(--nj-size-border-radius) !important;border-bottom-left-radius:var(--nj-size-border-radius) !important}.rounded-circle{border-radius:50% !important}.rounded-0{border-radius:0 !important}
